Source-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[src/trunk]: src/sys/arch/sun2/sun2 Fixed the known obio address range for th...



details:   https://anonhg.NetBSD.org/src/rev/070c67d634f7
branches:  trunk
changeset: 512650:070c67d634f7
user:      fredette <fredette%NetBSD.org@localhost>
date:      Thu Jul 12 19:24:40 2001 +0000

description:
Fixed the known obio address range for the Multibus
machines to avoid bwtwo matching on obio.

diffstat:

 sys/arch/sun2/sun2/obio.c |  10 +++++-----
 1 files changed, 5 insertions(+), 5 deletions(-)

diffs (25 lines):

diff -r 615123b9ebe7 -r 070c67d634f7 sys/arch/sun2/sun2/obio.c
--- a/sys/arch/sun2/sun2/obio.c Thu Jul 12 19:11:43 2001 +0000
+++ b/sys/arch/sun2/sun2/obio.c Thu Jul 12 19:24:40 2001 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: obio.c,v 1.4 2001/06/27 03:00:45 fredette Exp $        */
+/*     $NetBSD: obio.c,v 1.5 2001/07/12 19:24:40 fredette Exp $        */
 
 /*-
  * Copyright (c) 1996 The NetBSD Foundation, Inc.
@@ -204,11 +204,11 @@
 
        /*
         * Return nonzero if it's bad.  All sun2 Multibus
         * machines have all obio devices below 0x7f0000,
         * and all sun2 VME machines have all obio
         * devices at or above 0x7f0000.
         */
-       return ((!!cpu_has_multibus) != (pa < 0x7f0000));
+       return ((!!cpu_has_multibus) != (pa >= 0x2000 && pa < 0x4000));
 }
        
 int
@@ -204,11 +204,11 @@
        /*
         * Return nonzero if it's bad.  All sun2 Multibus
-        * machines have all obio devices below 0x7f0000,
-        * and all sun2 VME machines have all obio
-        * devices at or above 0x7f0000.
+        * machines have all obio devices between 0x2000
+        * and 0x4000, and all sun2 VME machines have all 
+        * obio devices outside of this range.
         */



Home | Main Index | Thread Index | Old Index